// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: proto/agent/v1/connection.proto
// Protobuf C++ Version: 7.35.1

#ifndef proto_2fagent_2fv1_2fconnection_2eproto_2epb_2eh
#define proto_2fagent_2fv1_2fconnection_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

// clang-format off
#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 7035001
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/generated_enum_reflection.h"
#include "google/protobuf/unknown_field_set.h"
#include "google/protobuf/timestamp.pb.h"
#include "google/protobuf/duration.pb.h"
#include "proto/aclk/v1/lib.pb.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_proto_2fagent_2fv1_2fconnection_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_proto_2fagent_2fv1_2fconnection_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_proto_2fagent_2fv1_2fconnection_2eproto;
}  // extern "C"
namespace agent {
namespace v1 {
enum ConnectionUpdateSource : int;
extern const uint32_t ConnectionUpdateSource_internal_data_[];
class AgentConfig;
struct AgentConfigGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern AgentConfigGlobalsTypeInternal AgentConfig_globals_;
extern const ::google::protobuf::internal::ClassDataFull AgentConfig_class_data_;
#else
extern const AgentConfigGlobalsTypeInternal AgentConfig_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class CloudConfig;
struct CloudConfigGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern CloudConfigGlobalsTypeInternal CloudConfig_globals_;
extern const ::google::protobuf::internal::ClassDataFull CloudConfig_class_data_;
#else
extern const CloudConfigGlobalsTypeInternal CloudConfig_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class Config;
struct ConfigGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern ConfigGlobalsTypeInternal Config_globals_;
extern const ::google::protobuf::internal::ClassDataFull Config_class_data_;
#else
extern const ConfigGlobalsTypeInternal Config_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class SendNodeInstances;
struct SendNodeInstancesGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern SendNodeInstancesGlobalsTypeInternal SendNodeInstances_globals_;
extern const ::google::protobuf::internal::ClassDataFull SendNodeInstances_class_data_;
#else
extern const SendNodeInstancesGlobalsTypeInternal SendNodeInstances_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
class UpdateAgentConnection;
struct UpdateAgentConnectionGlobalsTypeInternal;
#ifndef PROTOBUF_MESSAGE_GLOBALS
extern UpdateAgentConnectionGlobalsTypeInternal UpdateAgentConnection_globals_;
extern const ::google::protobuf::internal::ClassDataFull UpdateAgentConnection_class_data_;
#else
extern const UpdateAgentConnectionGlobalsTypeInternal UpdateAgentConnection_globals_;
#endif  // PROTOBUF_MESSAGE_GLOBALS
}  // namespace v1
}  // namespace agent
namespace google {
namespace protobuf {
template <>
internal::EnumTraitsT<::agent::v1::ConnectionUpdateSource_internal_data_>
    internal::EnumTraitsImpl::value<::agent::v1::ConnectionUpdateSource>;
}  // namespace protobuf
}  // namespace google

namespace agent {
namespace v1 {
enum ConnectionUpdateSource : int {
  CONNECTION_UPDATE_SOURCE_UNSPECIFIED = 0,
  CONNECTION_UPDATE_SOURCE_AGENT = 1,
  CONNECTION_UPDATE_SOURCE_LWT = 2,
  CONNECTION_UPDATE_SOURCE_HEURISTIC = 3,
  ConnectionUpdateSource_INT_MIN_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::min(),
  ConnectionUpdateSource_INT_MAX_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::max(),
};

extern const uint32_t ConnectionUpdateSource_internal_data_[];
inline constexpr ConnectionUpdateSource ConnectionUpdateSource_MIN =
    static_cast<ConnectionUpdateSource>(0);
inline constexpr ConnectionUpdateSource ConnectionUpdateSource_MAX =
    static_cast<ConnectionUpdateSource>(3);
[[nodiscard]] inline bool ConnectionUpdateSource_IsValid(int value) {
  return 0 <= value && value <= 3;
}
inline constexpr int ConnectionUpdateSource_ARRAYSIZE = 3 + 1;
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
ConnectionUpdateSource_descriptor();
[[nodiscard]] inline auto ProtobufInternalGetEnumDescriptor(ConnectionUpdateSource) {
  return ConnectionUpdateSource_descriptor();
}
template <typename T>
[[nodiscard]] const ::std::string& ConnectionUpdateSource_Name(T value) {
  static_assert(::std::is_same<T, ConnectionUpdateSource>::value ||
                    ::std::is_integral<T>::value,
                "Incorrect type passed to ConnectionUpdateSource_Name().");
  return ConnectionUpdateSource_Name(static_cast<ConnectionUpdateSource>(value));
}
template <>
[[nodiscard]] inline const ::std::string& ConnectionUpdateSource_Name(ConnectionUpdateSource value) {
  return ::google::protobuf::internal::NameOfDenseEnum<ConnectionUpdateSource_descriptor, 0, 3>(
      static_cast<int>(value));
}
[[nodiscard]] inline bool ConnectionUpdateSource_Parse(
    ::absl::string_view name, ConnectionUpdateSource* PROTOBUF_NONNULL value) {
  return ::google::protobuf::internal::ParseNamedEnum<ConnectionUpdateSource>(ConnectionUpdateSource_descriptor(), name,
                                           value);
}
using ::google::protobuf::internal::generated_enum::AbslParseFlag;
using ::google::protobuf::internal::generated_enum::AbslUnparseFlag;

// ===================================================================


// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED CloudConfig final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:agent.v1.CloudConfig) */ {
 public:
  inline CloudConfig() : CloudConfig(nullptr) {}
  ~CloudConfig() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(CloudConfig* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(CloudConfig));
  }
#endif

  template <typename = void>
  explicit constexpr CloudConfig(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline CloudConfig(const CloudConfig& from) : CloudConfig(nullptr, from) {}
  inline CloudConfig(CloudConfig&& from) noexcept : CloudConfig(nullptr, ::std::move(from)) {}
  inline CloudConfig& operator=(const CloudConfig& from) {
    CopyFrom(from);
    return *this;
  }
  inline CloudConfig& operator=(CloudConfig&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const CloudConfig& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<CloudConfig>(&CloudConfig_globals_);
  }
  static constexpr int kIndexInFileMessages = 3;
  friend void swap(CloudConfig& a, CloudConfig& b) { a.Swap(&b); }
  inline void Swap(CloudConfig* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(CloudConfig* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] CloudConfig* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<CloudConfig>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const CloudConfig& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const CloudConfig& from) { CloudConfig::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(CloudConfig* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "agent.v1.CloudConfig"; }

  explicit CloudConfig(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  CloudConfig(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const CloudConfig& from);
  CloudConfig(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, CloudConfig&& from) noexcept
      : CloudConfig(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kDashboardsFieldNumber = 1,
    kAlertNotificationsFieldNumber = 2,
  };
  // string dashboards = 1;
  void clear_dashboards() ;
  [[nodiscard]] const ::std::string& dashboards() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_dashboards(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_dashboards();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_dashboards();
  void set_allocated_dashboards(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_dashboards() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_dashboards(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_dashboards();

  public:
  // string alert_notifications = 2;
  void clear_alert_notifications() ;
  [[nodiscard]] const ::std::string& alert_notifications() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_alert_notifications(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_alert_notifications();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_alert_notifications();
  void set_allocated_alert_notifications(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_alert_notifications() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_alert_notifications(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_alert_notifications();

  public:
  // @@protoc_insertion_point(class_scope:agent.v1.CloudConfig)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<1, 2,
                          0, 58,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const CloudConfig& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr dashboards_;
    ::google::protobuf::internal::ArenaStringPtr alert_notifications_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_proto_2fagent_2fv1_2fconnection_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED AgentConfig final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:agent.v1.AgentConfig) */ {
 public:
  inline AgentConfig() : AgentConfig(nullptr) {}
  ~AgentConfig() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(AgentConfig* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(AgentConfig));
  }
#endif

  template <typename = void>
  explicit constexpr AgentConfig(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline AgentConfig(const AgentConfig& from) : AgentConfig(nullptr, from) {}
  inline AgentConfig(AgentConfig&& from) noexcept : AgentConfig(nullptr, ::std::move(from)) {}
  inline AgentConfig& operator=(const AgentConfig& from) {
    CopyFrom(from);
    return *this;
  }
  inline AgentConfig& operator=(AgentConfig&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const AgentConfig& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<AgentConfig>(&AgentConfig_globals_);
  }
  static constexpr int kIndexInFileMessages = 2;
  friend void swap(AgentConfig& a, AgentConfig& b) { a.Swap(&b); }
  inline void Swap(AgentConfig* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(AgentConfig* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] AgentConfig* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<AgentConfig>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const AgentConfig& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const AgentConfig& from) { AgentConfig::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(AgentConfig* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "agent.v1.AgentConfig"; }

  explicit AgentConfig(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  AgentConfig(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const AgentConfig& from);
  AgentConfig(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, AgentConfig&& from) noexcept
      : AgentConfig(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kDashboardsFieldNumber = 1,
    kAlertNotificationsFieldNumber = 2,
  };
  // string dashboards = 1;
  void clear_dashboards() ;
  [[nodiscard]] const ::std::string& dashboards() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_dashboards(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_dashboards();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_dashboards();
  void set_allocated_dashboards(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_dashboards() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_dashboards(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_dashboards();

  public:
  // string alert_notifications = 2;
  void clear_alert_notifications() ;
  [[nodiscard]] const ::std::string& alert_notifications() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_alert_notifications(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_alert_notifications();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_alert_notifications();
  void set_allocated_alert_notifications(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_alert_notifications() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_alert_notifications(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_alert_notifications();

  public:
  // @@protoc_insertion_point(class_scope:agent.v1.AgentConfig)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<1, 2,
                          0, 58,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const AgentConfig& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr dashboards_;
    ::google::protobuf::internal::ArenaStringPtr alert_notifications_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_proto_2fagent_2fv1_2fconnection_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED UpdateAgentConnection final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:agent.v1.UpdateAgentConnection) */ {
 public:
  inline UpdateAgentConnection() : UpdateAgentConnection(nullptr) {}
  ~UpdateAgentConnection() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(UpdateAgentConnection* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(UpdateAgentConnection));
  }
#endif

  template <typename = void>
  explicit constexpr UpdateAgentConnection(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline UpdateAgentConnection(const UpdateAgentConnection& from) : UpdateAgentConnection(nullptr, from) {}
  inline UpdateAgentConnection(UpdateAgentConnection&& from) noexcept : UpdateAgentConnection(nullptr, ::std::move(from)) {}
  inline UpdateAgentConnection& operator=(const UpdateAgentConnection& from) {
    CopyFrom(from);
    return *this;
  }
  inline UpdateAgentConnection& operator=(UpdateAgentConnection&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const UpdateAgentConnection& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<UpdateAgentConnection>(&UpdateAgentConnection_globals_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(UpdateAgentConnection& a, UpdateAgentConnection& b) { a.Swap(&b); }
  inline void Swap(UpdateAgentConnection* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(UpdateAgentConnection* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] UpdateAgentConnection* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<UpdateAgentConnection>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const UpdateAgentConnection& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const UpdateAgentConnection& from) { UpdateAgentConnection::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(UpdateAgentConnection* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "agent.v1.UpdateAgentConnection"; }

  explicit UpdateAgentConnection(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  UpdateAgentConnection(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const UpdateAgentConnection& from);
  UpdateAgentConnection(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, UpdateAgentConnection&& from) noexcept
      : UpdateAgentConnection(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kClaimIdFieldNumber = 1,
    kMqttBrokerAddrFieldNumber = 5,
    kUpdatedAtFieldNumber = 6,
    kSystemUptimeFieldNumber = 15,
    kAgentUptimeFieldNumber = 16,
    kSessionIdFieldNumber = 3,
    kReachableFieldNumber = 2,
    kUpdateSourceFieldNumber = 4,
    kVmqInstanceIdFieldNumber = 7,
    kCapabilitiesFieldNumber = 17,
  };
  // string claim_id = 1;
  void clear_claim_id() ;
  [[nodiscard]] const ::std::string& claim_id() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_claim_id(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_claim_id();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_claim_id();
  void set_allocated_claim_id(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_claim_id() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_claim_id(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_claim_id();

  public:
  // string mqtt_broker_addr = 5;
  void clear_mqtt_broker_addr() ;
  [[nodiscard]] const ::std::string& mqtt_broker_addr() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_mqtt_broker_addr(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_mqtt_broker_addr();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_mqtt_broker_addr();
  void set_allocated_mqtt_broker_addr(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_mqtt_broker_addr() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_mqtt_broker_addr(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_mqtt_broker_addr();

  public:
  // .google.protobuf.Timestamp updated_at = 6;
  [[nodiscard]] bool has_updated_at()
      const;
  void clear_updated_at() ;
  [[nodiscard]] const ::google::protobuf::Timestamp& updated_at() const;
  [[nodiscard]] ::google::protobuf::Timestamp* PROTOBUF_NULLABLE release_updated_at();
  ::google::protobuf::Timestamp* PROTOBUF_NONNULL mutable_updated_at();
  void set_allocated_updated_at(::google::protobuf::Timestamp* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_updated_at(::google::protobuf::Timestamp* PROTOBUF_NULLABLE value);
  ::google::protobuf::Timestamp* PROTOBUF_NULLABLE unsafe_arena_release_updated_at();

  private:
  const ::google::protobuf::Timestamp& _internal_updated_at() const;
  ::google::protobuf::Timestamp* PROTOBUF_NONNULL _internal_mutable_updated_at();

  public:
  // .google.protobuf.Duration system_uptime = 15;
  [[nodiscard]] bool has_system_uptime()
      const;
  void clear_system_uptime() ;
  [[nodiscard]] const ::google::protobuf::Duration& system_uptime() const;
  [[nodiscard]] ::google::protobuf::Duration* PROTOBUF_NULLABLE release_system_uptime();
  ::google::protobuf::Duration* PROTOBUF_NONNULL mutable_system_uptime();
  void set_allocated_system_uptime(::google::protobuf::Duration* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_system_uptime(::google::protobuf::Duration* PROTOBUF_NULLABLE value);
  ::google::protobuf::Duration* PROTOBUF_NULLABLE unsafe_arena_release_system_uptime();

  private:
  const ::google::protobuf::Duration& _internal_system_uptime() const;
  ::google::protobuf::Duration* PROTOBUF_NONNULL _internal_mutable_system_uptime();

  public:
  // .google.protobuf.Duration agent_uptime = 16;
  [[nodiscard]] bool has_agent_uptime()
      const;
  void clear_agent_uptime() ;
  [[nodiscard]] const ::google::protobuf::Duration& agent_uptime() const;
  [[nodiscard]] ::google::protobuf::Duration* PROTOBUF_NULLABLE release_agent_uptime();
  ::google::protobuf::Duration* PROTOBUF_NONNULL mutable_agent_uptime();
  void set_allocated_agent_uptime(::google::protobuf::Duration* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_agent_uptime(::google::protobuf::Duration* PROTOBUF_NULLABLE value);
  ::google::protobuf::Duration* PROTOBUF_NULLABLE unsafe_arena_release_agent_uptime();

  private:
  const ::google::protobuf::Duration& _internal_agent_uptime() const;
  ::google::protobuf::Duration* PROTOBUF_NONNULL _internal_mutable_agent_uptime();

  public:
  // int64 session_id = 3;
  void clear_session_id() ;
  [[nodiscard]] ::int64_t session_id() const;
  void set_session_id(::int64_t value);

  private:
  ::int64_t _internal_session_id() const;
  void _internal_set_session_id(::int64_t value);

  public:
  // bool reachable = 2;
  void clear_reachable() ;
  [[nodiscard]] bool reachable() const;
  void set_reachable(bool value);

  private:
  bool _internal_reachable() const;
  void _internal_set_reachable(bool value);

  public:
  // .agent.v1.ConnectionUpdateSource update_source = 4;
  void clear_update_source() ;
  [[nodiscard]] ::agent::v1::ConnectionUpdateSource update_source() const;
  void set_update_source(::agent::v1::ConnectionUpdateSource value);

  private:
  ::agent::v1::ConnectionUpdateSource _internal_update_source() const;
  void _internal_set_update_source(::agent::v1::ConnectionUpdateSource value);

  public:
  // int32 vmq_instance_id = 7;
  void clear_vmq_instance_id() ;
  [[nodiscard]] ::int32_t vmq_instance_id() const;
  void set_vmq_instance_id(::int32_t value);

  private:
  ::int32_t _internal_vmq_instance_id() const;
  void _internal_set_vmq_instance_id(::int32_t value);

  public:
  // repeated .aclk_lib.v1.Capability capabilities = 17;
  [[nodiscard]] int capabilities_size()
      const;
  private:
  int _internal_capabilities_size() const;

  public:
  void clear_capabilities() ;
  [[nodiscard]] const ::aclk_lib::v1::Capability& capabilities(int index) const;
  [[nodiscard]] ::aclk_lib::v1::Capability* PROTOBUF_NONNULL mutable_capabilities(int index);
  ::aclk_lib::v1::Capability* PROTOBUF_NONNULL add_capabilities();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::aclk_lib::v1::Capability>&
  capabilities() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::aclk_lib::v1::Capability>* PROTOBUF_NONNULL
  mutable_capabilities();

  private:
  const ::google::protobuf::RepeatedPtrField<::aclk_lib::v1::Capability>& _internal_capabilities() const;
  ::google::protobuf::RepeatedPtrField<::aclk_lib::v1::Capability>* PROTOBUF_NONNULL _internal_mutable_capabilities();

  public:
  // @@protoc_insertion_point(class_scope:agent.v1.UpdateAgentConnection)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<4, 10,
                          4, 71,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const UpdateAgentConnection& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr claim_id_;
    ::google::protobuf::internal::ArenaStringPtr mqtt_broker_addr_;
    ::google::protobuf::Timestamp* PROTOBUF_NULLABLE updated_at_;
    ::google::protobuf::Duration* PROTOBUF_NULLABLE system_uptime_;
    ::google::protobuf::Duration* PROTOBUF_NULLABLE agent_uptime_;
    ::int64_t session_id_;
    bool reachable_;
    int update_source_;
    ::int32_t vmq_instance_id_;
    ::google::protobuf::RepeatedPtrField< ::aclk_lib::v1::Capability > capabilities_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_proto_2fagent_2fv1_2fconnection_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED Config final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:agent.v1.Config) */ {
 public:
  inline Config() : Config(nullptr) {}
  ~Config() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(Config* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(Config));
  }
#endif

  template <typename = void>
  explicit constexpr Config(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline Config(const Config& from) : Config(nullptr, from) {}
  inline Config(Config&& from) noexcept : Config(nullptr, ::std::move(from)) {}
  inline Config& operator=(const Config& from) {
    CopyFrom(from);
    return *this;
  }
  inline Config& operator=(Config&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const Config& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<Config>(&Config_globals_);
  }
  static constexpr int kIndexInFileMessages = 4;
  friend void swap(Config& a, Config& b) { a.Swap(&b); }
  inline void Swap(Config* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Config* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] Config* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<Config>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Config& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Config& from) { Config::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(Config* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "agent.v1.Config"; }

  explicit Config(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  Config(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Config& from);
  Config(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, Config&& from) noexcept
      : Config(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kAgentConfigFieldNumber = 4,
    kCloudConfigFieldNumber = 5,
  };
  // .agent.v1.AgentConfig agent_config = 4;
  [[nodiscard]] bool has_agent_config()
      const;
  void clear_agent_config() ;
  [[nodiscard]] const ::agent::v1::AgentConfig& agent_config() const;
  [[nodiscard]] ::agent::v1::AgentConfig* PROTOBUF_NULLABLE release_agent_config();
  ::agent::v1::AgentConfig* PROTOBUF_NONNULL mutable_agent_config();
  void set_allocated_agent_config(::agent::v1::AgentConfig* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_agent_config(::agent::v1::AgentConfig* PROTOBUF_NULLABLE value);
  ::agent::v1::AgentConfig* PROTOBUF_NULLABLE unsafe_arena_release_agent_config();

  private:
  const ::agent::v1::AgentConfig& _internal_agent_config() const;
  ::agent::v1::AgentConfig* PROTOBUF_NONNULL _internal_mutable_agent_config();

  public:
  // .agent.v1.CloudConfig cloud_config = 5;
  [[nodiscard]] bool has_cloud_config()
      const;
  void clear_cloud_config() ;
  [[nodiscard]] const ::agent::v1::CloudConfig& cloud_config() const;
  [[nodiscard]] ::agent::v1::CloudConfig* PROTOBUF_NULLABLE release_cloud_config();
  ::agent::v1::CloudConfig* PROTOBUF_NONNULL mutable_cloud_config();
  void set_allocated_cloud_config(::agent::v1::CloudConfig* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_cloud_config(::agent::v1::CloudConfig* PROTOBUF_NULLABLE value);
  ::agent::v1::CloudConfig* PROTOBUF_NULLABLE unsafe_arena_release_cloud_config();

  private:
  const ::agent::v1::CloudConfig& _internal_cloud_config() const;
  ::agent::v1::CloudConfig* PROTOBUF_NONNULL _internal_mutable_cloud_config();

  public:
  // @@protoc_insertion_point(class_scope:agent.v1.Config)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<1, 2,
                          2, 0,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const Config& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::agent::v1::AgentConfig* PROTOBUF_NULLABLE agent_config_;
    ::agent::v1::CloudConfig* PROTOBUF_NULLABLE cloud_config_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_proto_2fagent_2fv1_2fconnection_2eproto;
};
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED SendNodeInstances final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:agent.v1.SendNodeInstances) */ {
 public:
  inline SendNodeInstances() : SendNodeInstances(nullptr) {}
  ~SendNodeInstances() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(SendNodeInstances* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(SendNodeInstances));
  }
#endif

  template <typename = void>
  explicit constexpr SendNodeInstances(::google::protobuf::internal::ConstantInitialized,
                           const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL
                               class_data);

  inline SendNodeInstances(const SendNodeInstances& from) : SendNodeInstances(nullptr, from) {}
  inline SendNodeInstances(SendNodeInstances&& from) noexcept : SendNodeInstances(nullptr, ::std::move(from)) {}
  inline SendNodeInstances& operator=(const SendNodeInstances& from) {
    CopyFrom(from);
    return *this;
  }
  inline SendNodeInstances& operator=(SendNodeInstances&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const SendNodeInstances& default_instance() {
    return *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<SendNodeInstances>(&SendNodeInstances_globals_);
  }
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(SendNodeInstances& a, SendNodeInstances& b) { a.Swap(&b); }
  inline void Swap(SendNodeInstances* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SendNodeInstances* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] SendNodeInstances* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<SendNodeInstances>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const SendNodeInstances& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const SendNodeInstances& from) { SendNodeInstances::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(SendNodeInstances* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "agent.v1.SendNodeInstances"; }

  explicit SendNodeInstances(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  SendNodeInstances(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const SendNodeInstances& from);
  SendNodeInstances(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, SendNodeInstances&& from) noexcept
      : SendNodeInstances(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_(
      const MessageLite& prototype,
      const ::google::protobuf::internal::TcParseTableBase* PROTOBUF_NULLABLE tc_table = nullptr);

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kClaimIdFieldNumber = 1,
    kSpaceIdFieldNumber = 3,
    kConfigFieldNumber = 2,
  };
  // string claim_id = 1;
  void clear_claim_id() ;
  [[nodiscard]] const ::std::string& claim_id() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_claim_id(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_claim_id();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_claim_id();
  void set_allocated_claim_id(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_claim_id() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_claim_id(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_claim_id();

  public:
  // string space_id = 3;
  void clear_space_id() ;
  [[nodiscard]] const ::std::string& space_id() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_space_id(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_space_id();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_space_id();
  void set_allocated_space_id(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_space_id() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_space_id(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_space_id();

  public:
  // .agent.v1.Config config = 2;
  [[nodiscard]] bool has_config()
      const;
  void clear_config() ;
  [[nodiscard]] const ::agent::v1::Config& config() const;
  [[nodiscard]] ::agent::v1::Config* PROTOBUF_NULLABLE release_config();
  ::agent::v1::Config* PROTOBUF_NONNULL mutable_config();
  void set_allocated_config(::agent::v1::Config* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_config(::agent::v1::Config* PROTOBUF_NULLABLE value);
  ::agent::v1::Config* PROTOBUF_NULLABLE unsafe_arena_release_config();

  private:
  const ::agent::v1::Config& _internal_config() const;
  ::agent::v1::Config* PROTOBUF_NONNULL _internal_mutable_config();

  public:
  // @@protoc_insertion_point(class_scope:agent.v1.SendNodeInstances)
 private:
  class _Internal;
  using ParseTableT_ =
      ::google::protobuf::internal::TcParseTable<2, 3,
                          1, 51,
                          2>;
  static constexpr ParseTableT_ InternalGenerateParseTable_(
      const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL class_data);
  friend class ::google::protobuf::internal::TcParser;
  #ifndef PROTOBUF_MESSAGE_GLOBALS
  static const ParseTableT_ _table_;
  #endif

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const SendNodeInstances& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr claim_id_;
    ::google::protobuf::internal::ArenaStringPtr space_id_;
    ::agent::v1::Config* PROTOBUF_NULLABLE config_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_proto_2fagent_2fv1_2fconnection_2eproto;
};

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// UpdateAgentConnection

// string claim_id = 1;
inline void UpdateAgentConnection::clear_claim_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.claim_id_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& UpdateAgentConnection::claim_id() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.UpdateAgentConnection.claim_id)
  return _internal_claim_id();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void UpdateAgentConnection::set_claim_id(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.claim_id_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:agent.v1.UpdateAgentConnection.claim_id)
}
inline ::std::string* PROTOBUF_NONNULL UpdateAgentConnection::mutable_claim_id()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_claim_id();
  // @@protoc_insertion_point(field_mutable:agent.v1.UpdateAgentConnection.claim_id)
  return _s;
}
inline const ::std::string& UpdateAgentConnection::_internal_claim_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.claim_id_.Get();
}
inline void UpdateAgentConnection::_internal_set_claim_id(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.claim_id_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL UpdateAgentConnection::_internal_mutable_claim_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.claim_id_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE UpdateAgentConnection::release_claim_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.UpdateAgentConnection.claim_id)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.claim_id_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.claim_id_.Set("", GetArena());
  }
  return released;
}
inline void UpdateAgentConnection::set_allocated_claim_id(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.claim_id_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.claim_id_.IsDefault()) {
    _impl_.claim_id_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:agent.v1.UpdateAgentConnection.claim_id)
}

// bool reachable = 2;
inline void UpdateAgentConnection::clear_reachable() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.reachable_ = false;
  ClearHasBit(_impl_._has_bits_[0], 0x00000040U);
}
inline bool UpdateAgentConnection::reachable() const {
  // @@protoc_insertion_point(field_get:agent.v1.UpdateAgentConnection.reachable)
  return _internal_reachable();
}
inline void UpdateAgentConnection::set_reachable(bool value) {
  _internal_set_reachable(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000040U);
  // @@protoc_insertion_point(field_set:agent.v1.UpdateAgentConnection.reachable)
}
inline bool UpdateAgentConnection::_internal_reachable() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.reachable_;
}
inline void UpdateAgentConnection::_internal_set_reachable(bool value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.reachable_ = value;
}

// int64 session_id = 3;
inline void UpdateAgentConnection::clear_session_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.session_id_ = ::int64_t{0};
  ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
}
inline ::int64_t UpdateAgentConnection::session_id() const {
  // @@protoc_insertion_point(field_get:agent.v1.UpdateAgentConnection.session_id)
  return _internal_session_id();
}
inline void UpdateAgentConnection::set_session_id(::int64_t value) {
  _internal_set_session_id(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  // @@protoc_insertion_point(field_set:agent.v1.UpdateAgentConnection.session_id)
}
inline ::int64_t UpdateAgentConnection::_internal_session_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.session_id_;
}
inline void UpdateAgentConnection::_internal_set_session_id(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.session_id_ = value;
}

// .agent.v1.ConnectionUpdateSource update_source = 4;
inline void UpdateAgentConnection::clear_update_source() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.update_source_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000080U);
}
inline ::agent::v1::ConnectionUpdateSource UpdateAgentConnection::update_source() const {
  // @@protoc_insertion_point(field_get:agent.v1.UpdateAgentConnection.update_source)
  return _internal_update_source();
}
inline void UpdateAgentConnection::set_update_source(::agent::v1::ConnectionUpdateSource value) {
  _internal_set_update_source(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000080U);
  // @@protoc_insertion_point(field_set:agent.v1.UpdateAgentConnection.update_source)
}
inline ::agent::v1::ConnectionUpdateSource UpdateAgentConnection::_internal_update_source() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return static_cast<::agent::v1::ConnectionUpdateSource>(_impl_.update_source_);
}
inline void UpdateAgentConnection::_internal_set_update_source(::agent::v1::ConnectionUpdateSource value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.update_source_ = value;
}

// string mqtt_broker_addr = 5;
inline void UpdateAgentConnection::clear_mqtt_broker_addr() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.mqtt_broker_addr_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& UpdateAgentConnection::mqtt_broker_addr() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.UpdateAgentConnection.mqtt_broker_addr)
  return _internal_mqtt_broker_addr();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void UpdateAgentConnection::set_mqtt_broker_addr(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.mqtt_broker_addr_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:agent.v1.UpdateAgentConnection.mqtt_broker_addr)
}
inline ::std::string* PROTOBUF_NONNULL UpdateAgentConnection::mutable_mqtt_broker_addr()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_mqtt_broker_addr();
  // @@protoc_insertion_point(field_mutable:agent.v1.UpdateAgentConnection.mqtt_broker_addr)
  return _s;
}
inline const ::std::string& UpdateAgentConnection::_internal_mqtt_broker_addr() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.mqtt_broker_addr_.Get();
}
inline void UpdateAgentConnection::_internal_set_mqtt_broker_addr(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.mqtt_broker_addr_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL UpdateAgentConnection::_internal_mutable_mqtt_broker_addr() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.mqtt_broker_addr_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE UpdateAgentConnection::release_mqtt_broker_addr() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.UpdateAgentConnection.mqtt_broker_addr)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.mqtt_broker_addr_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.mqtt_broker_addr_.Set("", GetArena());
  }
  return released;
}
inline void UpdateAgentConnection::set_allocated_mqtt_broker_addr(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.mqtt_broker_addr_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.mqtt_broker_addr_.IsDefault()) {
    _impl_.mqtt_broker_addr_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:agent.v1.UpdateAgentConnection.mqtt_broker_addr)
}

// .google.protobuf.Timestamp updated_at = 6;
inline bool UpdateAgentConnection::has_updated_at() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  PROTOBUF_ASSUME(!value || _impl_.updated_at_ != nullptr);
  return value;
}
inline const ::google::protobuf::Timestamp& UpdateAgentConnection::_internal_updated_at() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::google::protobuf::Timestamp* p = _impl_.updated_at_;
  return p != nullptr ? *p : *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<::google::protobuf::Timestamp>(&::google::protobuf::Timestamp_globals_);
}
inline const ::google::protobuf::Timestamp& UpdateAgentConnection::updated_at() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.UpdateAgentConnection.updated_at)
  return _internal_updated_at();
}
inline void UpdateAgentConnection::unsafe_arena_set_allocated_updated_at(
    ::google::protobuf::Timestamp* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.updated_at_);
  }
  _impl_.updated_at_ = reinterpret_cast<::google::protobuf::Timestamp*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:agent.v1.UpdateAgentConnection.updated_at)
}
inline ::google::protobuf::Timestamp* PROTOBUF_NULLABLE UpdateAgentConnection::release_updated_at() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::google::protobuf::Timestamp* released = _impl_.updated_at_;
  _impl_.updated_at_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::google::protobuf::Timestamp* PROTOBUF_NULLABLE UpdateAgentConnection::unsafe_arena_release_updated_at() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.UpdateAgentConnection.updated_at)

  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::google::protobuf::Timestamp* temp = _impl_.updated_at_;
  _impl_.updated_at_ = nullptr;
  return temp;
}
inline ::google::protobuf::Timestamp* PROTOBUF_NONNULL UpdateAgentConnection::_internal_mutable_updated_at() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.updated_at_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::google::protobuf::Timestamp>(GetArena());
    _impl_.updated_at_ = reinterpret_cast<::google::protobuf::Timestamp*>(p);
  }
  return _impl_.updated_at_;
}
inline ::google::protobuf::Timestamp* PROTOBUF_NONNULL UpdateAgentConnection::mutable_updated_at()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::google::protobuf::Timestamp* _msg = _internal_mutable_updated_at();
  // @@protoc_insertion_point(field_mutable:agent.v1.UpdateAgentConnection.updated_at)
  return _msg;
}
inline void UpdateAgentConnection::set_allocated_updated_at(::google::protobuf::Timestamp* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.updated_at_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(value)->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }

  _impl_.updated_at_ = reinterpret_cast<::google::protobuf::Timestamp*>(value);
  // @@protoc_insertion_point(field_set_allocated:agent.v1.UpdateAgentConnection.updated_at)
}

// int32 vmq_instance_id = 7;
inline void UpdateAgentConnection::clear_vmq_instance_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.vmq_instance_id_ = 0;
  ClearHasBit(_impl_._has_bits_[0], 0x00000100U);
}
inline ::int32_t UpdateAgentConnection::vmq_instance_id() const {
  // @@protoc_insertion_point(field_get:agent.v1.UpdateAgentConnection.vmq_instance_id)
  return _internal_vmq_instance_id();
}
inline void UpdateAgentConnection::set_vmq_instance_id(::int32_t value) {
  _internal_set_vmq_instance_id(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000100U);
  // @@protoc_insertion_point(field_set:agent.v1.UpdateAgentConnection.vmq_instance_id)
}
inline ::int32_t UpdateAgentConnection::_internal_vmq_instance_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.vmq_instance_id_;
}
inline void UpdateAgentConnection::_internal_set_vmq_instance_id(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.vmq_instance_id_ = value;
}

// .google.protobuf.Duration system_uptime = 15;
inline bool UpdateAgentConnection::has_system_uptime() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000008U);
  PROTOBUF_ASSUME(!value || _impl_.system_uptime_ != nullptr);
  return value;
}
inline const ::google::protobuf::Duration& UpdateAgentConnection::_internal_system_uptime() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::google::protobuf::Duration* p = _impl_.system_uptime_;
  return p != nullptr ? *p : *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<::google::protobuf::Duration>(&::google::protobuf::Duration_globals_);
}
inline const ::google::protobuf::Duration& UpdateAgentConnection::system_uptime() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.UpdateAgentConnection.system_uptime)
  return _internal_system_uptime();
}
inline void UpdateAgentConnection::unsafe_arena_set_allocated_system_uptime(
    ::google::protobuf::Duration* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.system_uptime_);
  }
  _impl_.system_uptime_ = reinterpret_cast<::google::protobuf::Duration*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:agent.v1.UpdateAgentConnection.system_uptime)
}
inline ::google::protobuf::Duration* PROTOBUF_NULLABLE UpdateAgentConnection::release_system_uptime() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::google::protobuf::Duration* released = _impl_.system_uptime_;
  _impl_.system_uptime_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::google::protobuf::Duration* PROTOBUF_NULLABLE UpdateAgentConnection::unsafe_arena_release_system_uptime() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.UpdateAgentConnection.system_uptime)

  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::google::protobuf::Duration* temp = _impl_.system_uptime_;
  _impl_.system_uptime_ = nullptr;
  return temp;
}
inline ::google::protobuf::Duration* PROTOBUF_NONNULL UpdateAgentConnection::_internal_mutable_system_uptime() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.system_uptime_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::google::protobuf::Duration>(GetArena());
    _impl_.system_uptime_ = reinterpret_cast<::google::protobuf::Duration*>(p);
  }
  return _impl_.system_uptime_;
}
inline ::google::protobuf::Duration* PROTOBUF_NONNULL UpdateAgentConnection::mutable_system_uptime()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::google::protobuf::Duration* _msg = _internal_mutable_system_uptime();
  // @@protoc_insertion_point(field_mutable:agent.v1.UpdateAgentConnection.system_uptime)
  return _msg;
}
inline void UpdateAgentConnection::set_allocated_system_uptime(::google::protobuf::Duration* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.system_uptime_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(value)->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  }

  _impl_.system_uptime_ = reinterpret_cast<::google::protobuf::Duration*>(value);
  // @@protoc_insertion_point(field_set_allocated:agent.v1.UpdateAgentConnection.system_uptime)
}

// .google.protobuf.Duration agent_uptime = 16;
inline bool UpdateAgentConnection::has_agent_uptime() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000010U);
  PROTOBUF_ASSUME(!value || _impl_.agent_uptime_ != nullptr);
  return value;
}
inline const ::google::protobuf::Duration& UpdateAgentConnection::_internal_agent_uptime() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::google::protobuf::Duration* p = _impl_.agent_uptime_;
  return p != nullptr ? *p : *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<::google::protobuf::Duration>(&::google::protobuf::Duration_globals_);
}
inline const ::google::protobuf::Duration& UpdateAgentConnection::agent_uptime() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.UpdateAgentConnection.agent_uptime)
  return _internal_agent_uptime();
}
inline void UpdateAgentConnection::unsafe_arena_set_allocated_agent_uptime(
    ::google::protobuf::Duration* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.agent_uptime_);
  }
  _impl_.agent_uptime_ = reinterpret_cast<::google::protobuf::Duration*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:agent.v1.UpdateAgentConnection.agent_uptime)
}
inline ::google::protobuf::Duration* PROTOBUF_NULLABLE UpdateAgentConnection::release_agent_uptime() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
  ::google::protobuf::Duration* released = _impl_.agent_uptime_;
  _impl_.agent_uptime_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::google::protobuf::Duration* PROTOBUF_NULLABLE UpdateAgentConnection::unsafe_arena_release_agent_uptime() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.UpdateAgentConnection.agent_uptime)

  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
  ::google::protobuf::Duration* temp = _impl_.agent_uptime_;
  _impl_.agent_uptime_ = nullptr;
  return temp;
}
inline ::google::protobuf::Duration* PROTOBUF_NONNULL UpdateAgentConnection::_internal_mutable_agent_uptime() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.agent_uptime_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::google::protobuf::Duration>(GetArena());
    _impl_.agent_uptime_ = reinterpret_cast<::google::protobuf::Duration*>(p);
  }
  return _impl_.agent_uptime_;
}
inline ::google::protobuf::Duration* PROTOBUF_NONNULL UpdateAgentConnection::mutable_agent_uptime()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  ::google::protobuf::Duration* _msg = _internal_mutable_agent_uptime();
  // @@protoc_insertion_point(field_mutable:agent.v1.UpdateAgentConnection.agent_uptime)
  return _msg;
}
inline void UpdateAgentConnection::set_allocated_agent_uptime(::google::protobuf::Duration* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.agent_uptime_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(value)->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
  }

  _impl_.agent_uptime_ = reinterpret_cast<::google::protobuf::Duration*>(value);
  // @@protoc_insertion_point(field_set_allocated:agent.v1.UpdateAgentConnection.agent_uptime)
}

// repeated .aclk_lib.v1.Capability capabilities = 17;
inline int UpdateAgentConnection::_internal_capabilities_size() const {
  return _internal_capabilities().size();
}
inline int UpdateAgentConnection::capabilities_size() const {
  return _internal_capabilities_size();
}
inline const ::aclk_lib::v1::Capability& UpdateAgentConnection::capabilities(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.UpdateAgentConnection.capabilities)
  return _internal_capabilities().Get(index);
}
inline ::aclk_lib::v1::Capability* PROTOBUF_NONNULL UpdateAgentConnection::mutable_capabilities(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:agent.v1.UpdateAgentConnection.capabilities)
  return _internal_mutable_capabilities()->Mutable(index);
}
inline ::aclk_lib::v1::Capability* PROTOBUF_NONNULL UpdateAgentConnection::add_capabilities()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::aclk_lib::v1::Capability* _add =
      _internal_mutable_capabilities()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBit(_impl_._has_bits_[0], 0x00000200U);
  // @@protoc_insertion_point(field_add:agent.v1.UpdateAgentConnection.capabilities)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::aclk_lib::v1::Capability>& UpdateAgentConnection::capabilities() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:agent.v1.UpdateAgentConnection.capabilities)
  return _internal_capabilities();
}
inline ::google::protobuf::RepeatedPtrField<::aclk_lib::v1::Capability>* PROTOBUF_NONNULL
UpdateAgentConnection::mutable_capabilities() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000200U);
  // @@protoc_insertion_point(field_mutable_list:agent.v1.UpdateAgentConnection.capabilities)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_capabilities();
}
inline const ::google::protobuf::RepeatedPtrField<::aclk_lib::v1::Capability>&
UpdateAgentConnection::_internal_capabilities() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.capabilities_;
}
inline ::google::protobuf::RepeatedPtrField<::aclk_lib::v1::Capability>* PROTOBUF_NONNULL
UpdateAgentConnection::_internal_mutable_capabilities() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.capabilities_;
}

// -------------------------------------------------------------------

// SendNodeInstances

// string claim_id = 1;
inline void SendNodeInstances::clear_claim_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.claim_id_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& SendNodeInstances::claim_id() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.SendNodeInstances.claim_id)
  return _internal_claim_id();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void SendNodeInstances::set_claim_id(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.claim_id_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:agent.v1.SendNodeInstances.claim_id)
}
inline ::std::string* PROTOBUF_NONNULL SendNodeInstances::mutable_claim_id()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_claim_id();
  // @@protoc_insertion_point(field_mutable:agent.v1.SendNodeInstances.claim_id)
  return _s;
}
inline const ::std::string& SendNodeInstances::_internal_claim_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.claim_id_.Get();
}
inline void SendNodeInstances::_internal_set_claim_id(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.claim_id_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL SendNodeInstances::_internal_mutable_claim_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.claim_id_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE SendNodeInstances::release_claim_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.SendNodeInstances.claim_id)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.claim_id_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.claim_id_.Set("", GetArena());
  }
  return released;
}
inline void SendNodeInstances::set_allocated_claim_id(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.claim_id_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.claim_id_.IsDefault()) {
    _impl_.claim_id_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:agent.v1.SendNodeInstances.claim_id)
}

// .agent.v1.Config config = 2;
inline bool SendNodeInstances::has_config() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  PROTOBUF_ASSUME(!value || _impl_.config_ != nullptr);
  return value;
}
inline void SendNodeInstances::clear_config() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.config_ != nullptr) _impl_.config_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
}
inline const ::agent::v1::Config& SendNodeInstances::_internal_config() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::agent::v1::Config* p = _impl_.config_;
  return p != nullptr ? *p : *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<::agent::v1::Config>(&::agent::v1::Config_globals_);
}
inline const ::agent::v1::Config& SendNodeInstances::config() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.SendNodeInstances.config)
  return _internal_config();
}
inline void SendNodeInstances::unsafe_arena_set_allocated_config(
    ::agent::v1::Config* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.config_);
  }
  _impl_.config_ = reinterpret_cast<::agent::v1::Config*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:agent.v1.SendNodeInstances.config)
}
inline ::agent::v1::Config* PROTOBUF_NULLABLE SendNodeInstances::release_config() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::agent::v1::Config* released = _impl_.config_;
  _impl_.config_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::agent::v1::Config* PROTOBUF_NULLABLE SendNodeInstances::unsafe_arena_release_config() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.SendNodeInstances.config)

  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::agent::v1::Config* temp = _impl_.config_;
  _impl_.config_ = nullptr;
  return temp;
}
inline ::agent::v1::Config* PROTOBUF_NONNULL SendNodeInstances::_internal_mutable_config() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.config_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::agent::v1::Config>(GetArena());
    _impl_.config_ = reinterpret_cast<::agent::v1::Config*>(p);
  }
  return _impl_.config_;
}
inline ::agent::v1::Config* PROTOBUF_NONNULL SendNodeInstances::mutable_config()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::agent::v1::Config* _msg = _internal_mutable_config();
  // @@protoc_insertion_point(field_mutable:agent.v1.SendNodeInstances.config)
  return _msg;
}
inline void SendNodeInstances::set_allocated_config(::agent::v1::Config* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.config_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = value->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }

  _impl_.config_ = reinterpret_cast<::agent::v1::Config*>(value);
  // @@protoc_insertion_point(field_set_allocated:agent.v1.SendNodeInstances.config)
}

// string space_id = 3;
inline void SendNodeInstances::clear_space_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.space_id_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& SendNodeInstances::space_id() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.SendNodeInstances.space_id)
  return _internal_space_id();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void SendNodeInstances::set_space_id(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.space_id_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:agent.v1.SendNodeInstances.space_id)
}
inline ::std::string* PROTOBUF_NONNULL SendNodeInstances::mutable_space_id()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_space_id();
  // @@protoc_insertion_point(field_mutable:agent.v1.SendNodeInstances.space_id)
  return _s;
}
inline const ::std::string& SendNodeInstances::_internal_space_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.space_id_.Get();
}
inline void SendNodeInstances::_internal_set_space_id(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.space_id_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL SendNodeInstances::_internal_mutable_space_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.space_id_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE SendNodeInstances::release_space_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.SendNodeInstances.space_id)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.space_id_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.space_id_.Set("", GetArena());
  }
  return released;
}
inline void SendNodeInstances::set_allocated_space_id(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.space_id_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.space_id_.IsDefault()) {
    _impl_.space_id_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:agent.v1.SendNodeInstances.space_id)
}

// -------------------------------------------------------------------

// AgentConfig

// string dashboards = 1;
inline void AgentConfig::clear_dashboards() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dashboards_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& AgentConfig::dashboards() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.AgentConfig.dashboards)
  return _internal_dashboards();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void AgentConfig::set_dashboards(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.dashboards_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:agent.v1.AgentConfig.dashboards)
}
inline ::std::string* PROTOBUF_NONNULL AgentConfig::mutable_dashboards()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_dashboards();
  // @@protoc_insertion_point(field_mutable:agent.v1.AgentConfig.dashboards)
  return _s;
}
inline const ::std::string& AgentConfig::_internal_dashboards() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.dashboards_.Get();
}
inline void AgentConfig::_internal_set_dashboards(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dashboards_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL AgentConfig::_internal_mutable_dashboards() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.dashboards_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE AgentConfig::release_dashboards() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.AgentConfig.dashboards)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.dashboards_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.dashboards_.Set("", GetArena());
  }
  return released;
}
inline void AgentConfig::set_allocated_dashboards(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.dashboards_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.dashboards_.IsDefault()) {
    _impl_.dashboards_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:agent.v1.AgentConfig.dashboards)
}

// string alert_notifications = 2;
inline void AgentConfig::clear_alert_notifications() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.alert_notifications_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& AgentConfig::alert_notifications() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.AgentConfig.alert_notifications)
  return _internal_alert_notifications();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void AgentConfig::set_alert_notifications(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.alert_notifications_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:agent.v1.AgentConfig.alert_notifications)
}
inline ::std::string* PROTOBUF_NONNULL AgentConfig::mutable_alert_notifications()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_alert_notifications();
  // @@protoc_insertion_point(field_mutable:agent.v1.AgentConfig.alert_notifications)
  return _s;
}
inline const ::std::string& AgentConfig::_internal_alert_notifications() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.alert_notifications_.Get();
}
inline void AgentConfig::_internal_set_alert_notifications(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.alert_notifications_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL AgentConfig::_internal_mutable_alert_notifications() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.alert_notifications_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE AgentConfig::release_alert_notifications() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.AgentConfig.alert_notifications)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.alert_notifications_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.alert_notifications_.Set("", GetArena());
  }
  return released;
}
inline void AgentConfig::set_allocated_alert_notifications(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.alert_notifications_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.alert_notifications_.IsDefault()) {
    _impl_.alert_notifications_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:agent.v1.AgentConfig.alert_notifications)
}

// -------------------------------------------------------------------

// CloudConfig

// string dashboards = 1;
inline void CloudConfig::clear_dashboards() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dashboards_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::std::string& CloudConfig::dashboards() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.CloudConfig.dashboards)
  return _internal_dashboards();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void CloudConfig::set_dashboards(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.dashboards_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:agent.v1.CloudConfig.dashboards)
}
inline ::std::string* PROTOBUF_NONNULL CloudConfig::mutable_dashboards()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_dashboards();
  // @@protoc_insertion_point(field_mutable:agent.v1.CloudConfig.dashboards)
  return _s;
}
inline const ::std::string& CloudConfig::_internal_dashboards() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.dashboards_.Get();
}
inline void CloudConfig::_internal_set_dashboards(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.dashboards_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL CloudConfig::_internal_mutable_dashboards() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.dashboards_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE CloudConfig::release_dashboards() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.CloudConfig.dashboards)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.dashboards_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.dashboards_.Set("", GetArena());
  }
  return released;
}
inline void CloudConfig::set_allocated_dashboards(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.dashboards_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.dashboards_.IsDefault()) {
    _impl_.dashboards_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:agent.v1.CloudConfig.dashboards)
}

// string alert_notifications = 2;
inline void CloudConfig::clear_alert_notifications() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.alert_notifications_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::std::string& CloudConfig::alert_notifications() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.CloudConfig.alert_notifications)
  return _internal_alert_notifications();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void CloudConfig::set_alert_notifications(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  _impl_.alert_notifications_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:agent.v1.CloudConfig.alert_notifications)
}
inline ::std::string* PROTOBUF_NONNULL CloudConfig::mutable_alert_notifications()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::std::string* _s = _internal_mutable_alert_notifications();
  // @@protoc_insertion_point(field_mutable:agent.v1.CloudConfig.alert_notifications)
  return _s;
}
inline const ::std::string& CloudConfig::_internal_alert_notifications() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.alert_notifications_.Get();
}
inline void CloudConfig::_internal_set_alert_notifications(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.alert_notifications_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL CloudConfig::_internal_mutable_alert_notifications() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.alert_notifications_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE CloudConfig::release_alert_notifications() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.CloudConfig.alert_notifications)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000002U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  auto* released = _impl_.alert_notifications_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.alert_notifications_.Set("", GetArena());
  }
  return released;
}
inline void CloudConfig::set_allocated_alert_notifications(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  _impl_.alert_notifications_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.alert_notifications_.IsDefault()) {
    _impl_.alert_notifications_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:agent.v1.CloudConfig.alert_notifications)
}

// -------------------------------------------------------------------

// Config

// .agent.v1.AgentConfig agent_config = 4;
inline bool Config::has_agent_config() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000001U);
  PROTOBUF_ASSUME(!value || _impl_.agent_config_ != nullptr);
  return value;
}
inline void Config::clear_agent_config() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.agent_config_ != nullptr) _impl_.agent_config_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
}
inline const ::agent::v1::AgentConfig& Config::_internal_agent_config() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::agent::v1::AgentConfig* p = _impl_.agent_config_;
  return p != nullptr ? *p : *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<::agent::v1::AgentConfig>(&::agent::v1::AgentConfig_globals_);
}
inline const ::agent::v1::AgentConfig& Config::agent_config() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.Config.agent_config)
  return _internal_agent_config();
}
inline void Config::unsafe_arena_set_allocated_agent_config(
    ::agent::v1::AgentConfig* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.agent_config_);
  }
  _impl_.agent_config_ = reinterpret_cast<::agent::v1::AgentConfig*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:agent.v1.Config.agent_config)
}
inline ::agent::v1::AgentConfig* PROTOBUF_NULLABLE Config::release_agent_config() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::agent::v1::AgentConfig* released = _impl_.agent_config_;
  _impl_.agent_config_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::agent::v1::AgentConfig* PROTOBUF_NULLABLE Config::unsafe_arena_release_agent_config() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.Config.agent_config)

  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::agent::v1::AgentConfig* temp = _impl_.agent_config_;
  _impl_.agent_config_ = nullptr;
  return temp;
}
inline ::agent::v1::AgentConfig* PROTOBUF_NONNULL Config::_internal_mutable_agent_config() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.agent_config_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::agent::v1::AgentConfig>(GetArena());
    _impl_.agent_config_ = reinterpret_cast<::agent::v1::AgentConfig*>(p);
  }
  return _impl_.agent_config_;
}
inline ::agent::v1::AgentConfig* PROTOBUF_NONNULL Config::mutable_agent_config()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::agent::v1::AgentConfig* _msg = _internal_mutable_agent_config();
  // @@protoc_insertion_point(field_mutable:agent.v1.Config.agent_config)
  return _msg;
}
inline void Config::set_allocated_agent_config(::agent::v1::AgentConfig* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.agent_config_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = value->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }

  _impl_.agent_config_ = reinterpret_cast<::agent::v1::AgentConfig*>(value);
  // @@protoc_insertion_point(field_set_allocated:agent.v1.Config.agent_config)
}

// .agent.v1.CloudConfig cloud_config = 5;
inline bool Config::has_cloud_config() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000002U);
  PROTOBUF_ASSUME(!value || _impl_.cloud_config_ != nullptr);
  return value;
}
inline void Config::clear_cloud_config() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.cloud_config_ != nullptr) _impl_.cloud_config_->Clear();
  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
}
inline const ::agent::v1::CloudConfig& Config::_internal_cloud_config() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::agent::v1::CloudConfig* p = _impl_.cloud_config_;
  return p != nullptr ? *p : *::google::protobuf::internal::MessageGlobalsBase::ToDefaultInstance<::agent::v1::CloudConfig>(&::agent::v1::CloudConfig_globals_);
}
inline const ::agent::v1::CloudConfig& Config::cloud_config() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:agent.v1.Config.cloud_config)
  return _internal_cloud_config();
}
inline void Config::unsafe_arena_set_allocated_cloud_config(
    ::agent::v1::CloudConfig* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.cloud_config_);
  }
  _impl_.cloud_config_ = reinterpret_cast<::agent::v1::CloudConfig*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:agent.v1.Config.cloud_config)
}
inline ::agent::v1::CloudConfig* PROTOBUF_NULLABLE Config::release_cloud_config() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::agent::v1::CloudConfig* released = _impl_.cloud_config_;
  _impl_.cloud_config_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::agent::v1::CloudConfig* PROTOBUF_NULLABLE Config::unsafe_arena_release_cloud_config() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:agent.v1.Config.cloud_config)

  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::agent::v1::CloudConfig* temp = _impl_.cloud_config_;
  _impl_.cloud_config_ = nullptr;
  return temp;
}
inline ::agent::v1::CloudConfig* PROTOBUF_NONNULL Config::_internal_mutable_cloud_config() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.cloud_config_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::agent::v1::CloudConfig>(GetArena());
    _impl_.cloud_config_ = reinterpret_cast<::agent::v1::CloudConfig*>(p);
  }
  return _impl_.cloud_config_;
}
inline ::agent::v1::CloudConfig* PROTOBUF_NONNULL Config::mutable_cloud_config()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::agent::v1::CloudConfig* _msg = _internal_mutable_cloud_config();
  // @@protoc_insertion_point(field_mutable:agent.v1.Config.cloud_config)
  return _msg;
}
inline void Config::set_allocated_cloud_config(::agent::v1::CloudConfig* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.cloud_config_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = value->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }

  _impl_.cloud_config_ = reinterpret_cast<::agent::v1::CloudConfig*>(value);
  // @@protoc_insertion_point(field_set_allocated:agent.v1.Config.cloud_config)
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace v1
}  // namespace agent


namespace google {
namespace protobuf {

template <>
struct is_proto_enum<::agent::v1::ConnectionUpdateSource> : std::true_type {};
template <>
inline const EnumDescriptor* PROTOBUF_NONNULL GetEnumDescriptor<::agent::v1::ConnectionUpdateSource>() {
  return ::agent::v1::ConnectionUpdateSource_descriptor();
}

}  // namespace protobuf
}  // namespace google

// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"
// clang-format on

#endif  // proto_2fagent_2fv1_2fconnection_2eproto_2epb_2eh
